import { Component, Input, OnInit } from "@angular/core";
import { History } from "../../../../models/data/data.model";
import { UserListQuery } from "../../../../models/graphql/query.model";
import { Server } from "../../../../models/data/server.model";
import { DataService } from "../../../../services/data/data.service";
import { AuthService } from "../../../../services/auth/auth.service";
import { SpinnerService } from "../../../../services/spinner/spinner.service";
import { ToastService } from "../../../../services/toast/toast.service";
import { ConfirmationDialogService } from "../../../../services/confirmation-dialog/confirmation-dialog.service";
import { FormBuilder } from "@angular/forms";
import { TranslateService } from "@ngx-translate/core";
import { ActivatedRoute } from "@angular/router";
import { SidebarService } from "../../../../services/sidebar/sidebar.service";

@Component({
  selector: "app-history-btn",
  templateUrl: "./history-btn.component.html",
  styleUrls: ["./history-btn.component.scss"]
})
export class HistoryBtnComponent implements OnInit {

  @Input() id: number = 0;
  @Input() query: string = "";
  @Input() translationKey: string = "";

  public history: History[] = [];

  public showSidebar: boolean = false;
  private server: Server = {};

  public constructor(
    private authService: AuthService,
    private spinner: SpinnerService,
    private toastService: ToastService,
    private confirmDialog: ConfirmationDialogService,
    private fb: FormBuilder,
    private translate: TranslateService,
    private data: DataService,
    private route: ActivatedRoute,
    private sidebar: SidebarService
  ) {
  }

  public ngOnInit(): void {
    this.server = this.sidebar.server$.value ?? {};
  }

  public openHistory(): void {
    this.showSidebar = true;
    this.data.query<UserListQuery>(this.query, {
        serverId: this.server.id, userId: this.id
      },
      (x: { servers: Server[] }) => {
        return x.servers[0];
      }
    ).subscribe(data => {
      this.history = data.users[0].history ?? [];
      this.spinner.hideSpinner();
    });


    let oldHistory: Partial<History> = {};
    for (const history of this.history) {
      const attributes = Object.keys(history).map((key) => {
        return key;
      });
      for (const attribute of attributes) {
        if (history[attribute] === oldHistory[attribute]) {
          delete oldHistory[attribute];
        }
      }

      oldHistory = history;
    }
  }

  public getAttributeTranslationKey(key: string): string {
    return `common.history.${key}`;
  }

}
